@@ -5,7 +5,7 @@ use warnings;
 use Scalar::Util qw/reftype blessed/;
 use MooX::ReturnModifiers qw/return_modifiers/;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use constant ro       => 'ro';
 use constant is_ro    => ( is => ro );
@@ -31,7 +31,7 @@ sub import {
         while (@attr) {
             my @names = ref $attr[0] eq 'ARRAY' ? @{ shift @attr } : shift @attr;
             my @spec = @{ shift @attr };
-            # push either nan or a default 
+            
             push @spec, delete $spec[2]->{default}; 
             for (@names) {
                 unshift @spec, 'set' if $_ =~ m/^\+/ and ( !$spec[0] || $spec[0] ne 'set' );
@@ -58,7 +58,6 @@ sub construct_attribute {
    
     if ( ref $spec[1] eq 'Type::Tiny' ) { 
         $attr{isa} = $spec[1];
-        # pop either nan or the default
         $spec[1] = pop @spec;
     } 
     
@@ -71,7 +70,6 @@ sub construct_attribute {
 
 sub _clone {
     my ($to_clone) = @_;
-
     my $blessed = blessed $to_clone;
     my $clone   = _deep_clone($to_clone);
     return $blessed ? bless $clone, $blessed : $clone;
@@ -90,14 +88,13 @@ sub _deep_clone {
 
 __END__
 
-
 =head1 NAME
 
 MooX::LazierAttributes - Lazier Attributes.
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
@@ -130,7 +127,7 @@ Version 0.13
 
     ... Extending .....
 
-    package Extends::Hello::World;
+    `package Extends::Hello::World;
 
     use Moo;
     use MooX::LazierAttributes;
@@ -170,6 +167,26 @@ Version 0.13
         return My::Thing->new();
     }
 
+    ... Moo -> Moose ...
+
+    package Hello::World;
+    
+    use Moose;
+    use MooX::LazierAttributes qw/is_ro rw lzy bld/;
+    use Types::Standard qw/Str HashRef ArrayRef Object/;
+
+    attributes (
+        one   => [Str], # defaults to be ro
+        two   => [HashRef],
+        three => [Object, { lzy, bld }],
+        [qw/four five six/] => [rw, Str, { default => 'ruling the world' }],
+    );
+
+    has seven => ( is_ro, lzy, isa => ArrayRef, default => sub { [qw/a b c/] });
+
+    sub _build_three { 
+        return My::Thing->new();
+    }
 
 =head1 EXPORT
 
